==> hubzero-cms-1.2.2_1.2.2.8.orig.tar.gz: hubzero-cms-1.2.2-1.2.2.8/cms/components/com_support/views/media/tmpl/list.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

$no_html = JRequest::getInt('no_html', 0);

$assets = $this->model->attachments('list', array(
	'ticket'  => $this->ticket,
	'comment_id' => $this->comment
));
if ($assets->total() > 0) 
{ 
	$i = 0;
	foreach ($assets as $asset)
	{
		$view = new JView(array(
			'name'   => 'media',
			'layout' => '_asset'
		));
		$view->i          = $i;
		$view->option     = $this->option;
		$view->controller = $this->controller;
		$view->asset      = $asset;
		$view->no_html    = $no_html;
		$view->display();

		$i++;
	}
}

==> hubzero-cms-1.3.0_1.3.0.3.orig.tar.gz: hubzero-cms-1.3.0-1.3.0.3/cms/components/com_support/views/media/tmpl/list.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

$no_html = JRequest::getInt('no_html', 0);

$assets = $this->model->attachments('list', array(
	'ticket'  => $this->ticket,
	'comment_id' => $this->comment
));
if ($assets->total() > 0)
{
	$i = 0;
	foreach ($assets as $asset)
	{
		$this->view('_asset')
		     ->set('i', $i)
		     ->set('option', $this->option)
		     ->set('controller', $this->controller)
		     ->set('asset', $asset)
		     ->set('no_html', $no_html)
		     ->display();

		$i++;
	}
}
